#
# spec file for package rbac-manager
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


Name:           rbac-manager
Version:        1.4.2
Release:        1.8
Summary:        Kubernetes operator for easier RBAC management
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/FairwindsOps/rbac-manager
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.17
ExcludeArch:    s390
ExcludeArch:    %{ix86}
%{go_nostrip}

%description
RBAC Manager is designed to simplify authorization in Kubernetes.
This is an operator that supports declarative configuration for RBAC with new custom resources.
Instead of managing role bindings or service accounts directly, you can specify a desired state and RBAC Manager will make the necessary changes to achieve that state.

%package k8s-yaml
Summary:        Kubernetes yaml file to run rbac-manager
Group:          System/Management
BuildArch:      noarch

%description k8s-yaml
This package contains the yaml file requried to download and run the
rbac-manager in a kubernetes cluster.

%prep
%setup -qa1

%build
go build -mod vendor -buildmode=pie -a -o rbac-manager ./cmd/manager/main.go

%check
make test

%install
mkdir -p %{buildroot}%{_sbindir}/
install -D -m 0755 rbac-manager %{buildroot}%{_sbindir}/

# Install provided yaml file to download and run the rbac-manager
mkdir -p %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
install -m 0644 deploy/0_namespace.yaml %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
install -m 0644 deploy/1_rbac.yaml %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
install -m 0644 deploy/2_crd.yaml %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
install -m 0644 deploy/3_deployment.yaml %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
sed -i -e 's|image: "quay.io/reactiveops/rbac-manager:.*|image: "kubic/rbac-manager:%{version}"|g' %{buildroot}%{_datadir}/k8s-yaml/rbac-manager/3_deployment.yaml

%files
%license LICENSE
%doc docs/* examples
%{_sbindir}/rbac-manager

%files k8s-yaml
%dir %{_datarootdir}/k8s-yaml
%{_datarootdir}/k8s-yaml/rbac-manager

%changelog
* Mon Nov 28 2022 alexandre.vicenzi@suse.com
- Update to version 1.4.2:
  * Updated dependencies
  * Fix helm syntax (#325)
  * Support automountServiceAccountToken in Service Accounts (#324)
  * Allow empty subjects list (#323)
  * Fix an issue where we don't return errors (#322)
* Fri Mar 25 2022 alexandre.vicenzi@suse.com
- Update to version 1.1.0:
  * Update documentation
  * Bugfixes
* Fri Apr  9 2021 alexandre.vicenzi@suse.com
- Update to version 0.10.0:
  * Update dependencies and change metrics port (#162)
  * fix typo (#161)
  * updating CRD apiversion to v1 (#156)
  * Add brief design doc (#150)
  * delete vendor folder and dep files (#147)
  * Bump sigs.k8s.io/controller-runtime from 0.6.2 to 0.6.3 (#146)
  * Bump sigs.k8s.io/controller-runtime from 0.6.0 to 0.6.2 (#142)
  * Enable all known auth methods (#143)
  * update all.yaml to use recent v0.9.4 release (#140)
  * Update x/text to 0.3.3 for CVE (#139)
* Fri Feb 26 2021 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 0.9.4
  - Fix case where rbac-manager doesn't handle the namespace
    that does not exist and is later created
  - Fix case where rules for non-existing namespaces will be
    ignored forever
  - Bump sigs.k8s.io/controller-runtime from 0.5.1 to 0.5.2
  - Bump sigs.k8s.io/controller-runtime from 0.5.2 to 0.6.0
  - Update x/text to 0.3.3 for CVE
  - update yaml manifest to v0.9.2
  - Bump sigs.k8s.io/controller-runtime from 0.1.11 to 0.5.1
  - using numeric user in Dockerfile for PSP
* Tue Mar  3 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.9.2
  - Fixes major bug which will cause deletion and re-creation of
    a service account
* Tue Feb 18 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.9.1
  - Fix klog flag usage
- Remove unused vendor.tar.gz source
* Wed Nov  6 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.9.0
  - You can now specify service account image pull secrets
  - Versioning now happens automagically.
* Sun Oct 27 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.8.4
  - bump sigs.k8s.io/controller-runtime to 0.3.0
  - Added a metrics endpoint
- vendor.tar.gz: update
- Use official kubic image in k8s.yaml file
* Mon Sep 30 2019 Jan Engelhardt <jengelh@inai.de>
- Use modern tar options.
* Fri Sep 27 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.8.3
  - Added mutex to prevent reconciler loops from overlapping.
* Mon Sep 16 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.8.2
  - Reverted breaking label selector change.
  - Corrected version in log output
* Sun Jul 21 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to rbac-manager 0.8.0
  - detecting changes to role bindings owned by RBAC Definitions
    and repairing to desired state (#52)
  - initial work on watching resources owned by rbac definitions
  - improved reconciliation logic mostly working, better tests still needed
  - back to controller-runtime for namespace
* Thu May 23 2019 Thorsten Kukuk <kukuk@suse.com>
- Initial version
